==> 1.2025.316.6.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/searchbox/searchbox_browser_proxy.js <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import { PageCallbackRouter, PageHandler } from '//resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
export function createAutocompleteMatch() {
    return {
        a11yLabel: { data: [] },
        actions: [],
        allowedToBeDefaultMatch: false,
        isSearchType: false,
        isEnterpriseSearchAggregatorPeopleType: false,
        swapContentsAndDescription: false,
        supportsDeletion: false,
        suggestionGroupId: -1,
        contents: { data: [] },
        contentsClass: [{ offset: 0, style: 0 }],
        description: { data: [] },
        descriptionClass: [{ offset: 0, style: 0 }],
        destinationUrl: { url: '' },
        inlineAutocompletion: { data: [] },
        fillIntoEdit: { data: [] },
        iconPath: '',
        iconUrl: { url: '' },
        imageDominantColor: '',
        imageUrl: '',
        isNoncannedAimSuggestion: false,
        removeButtonA11yLabel: { data: [] },
        type: '',
        isRichSuggestion: false,
        isWeatherAnswerSuggestion: null,
        answer: null,
        tailSuggestCommonPrefix: null,
        hasInstantKeyword: false,
        keywordChipHint: '',
        keywordChipA11y: '',
    };
}
export class SearchboxBrowserProxy {
    static getInstance() {
        return instance || (instance = new SearchboxBrowserProxy());
    }
    static setInstance(newInstance) {
        instance = newInstance;
    }
    handler;
    callbackRouter;
    constructor() {
        this.handler = PageHandler.getRemote();
        this.callbackRouter = new PageCallbackRouter();
        this.handler.setPage(this.callbackRouter.$.bindNewPipeAndPassRemote());
    }
}
let instance = null;

==> 1.2025.344.7.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/searchbox/searchbox_browser_proxy.js <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import { PageCallbackRouter, PageHandler } from '//resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
export function createAutocompleteMatch() {
    return {
        isHidden: false,
        a11yLabel: '',
        actions: [],
        allowedToBeDefaultMatch: false,
        isSearchType: false,
        isEnterpriseSearchAggregatorPeopleType: false,
        swapContentsAndDescription: false,
        supportsDeletion: false,
        suggestionGroupId: -1,
        contents: '',
        contentsClass: [{ offset: 0, style: 0 }],
        description: '',
        descriptionClass: [{ offset: 0, style: 0 }],
        destinationUrl: { url: '' },
        inlineAutocompletion: '',
        fillIntoEdit: '',
        iconPath: '',
        iconUrl: { url: '' },
        imageDominantColor: '',
        imageUrl: '',
        isNoncannedAimSuggestion: false,
        removeButtonA11yLabel: '',
        type: '',
        isRichSuggestion: false,
        isWeatherAnswerSuggestion: null,
        answer: null,
        tailSuggestCommonPrefix: null,
        hasInstantKeyword: false,
        keywordChipHint: '',
        keywordChipA11y: '',
    };
}
export class SearchboxBrowserProxy {
    static getInstance() {
        return instance || (instance = new SearchboxBrowserProxy());
    }
    static setInstance(newInstance) {
        instance = newInstance;
    }
    handler;
    callbackRouter;
    constructor() {
        this.handler = PageHandler.getRemote();
        this.callbackRouter = new PageCallbackRouter();
        this.handler.setPage(this.callbackRouter.$.bindNewPipeAndPassRemote());
    }
}
let instance = null;
